@@ -1,4 +1,6 @@
-test_that("atomic vectors of length 1", {
+# what_is_it ----
+## Test 1: atomic vectors of length 1 ----
+test_that("what_is_it Test 1: atomic vectors of length 1", {
   expect_identical(what_is_it(NULL), "`NULL`")
   expect_identical(what_is_it(TRUE), "`TRUE`")
   expect_identical(what_is_it(NA), "`NA`")
@@ -8,7 +10,8 @@ test_that("atomic vectors of length 1", {
   expect_identical(what_is_it(2.42), "`2.42`")
 })
 
-test_that("vectors", {
+## Test 2: vectors ----
+test_that("what_is_it Test 2: vectors", {
   expect_identical(what_is_it(letters), "a character vector")
   expect_identical(what_is_it(1:10), "an integer vector")
   expect_identical(what_is_it(c(1.2, 3)), "a double vector")
@@ -16,7 +19,8 @@ test_that("vectors", {
   expect_identical(what_is_it(list(1, letters, TRUE)), "a list")
 })
 
-test_that("S3 objects", {
+## Test 3: S3 objects ----
+test_that("what_is_it Test 3: S3 objects", {
   expect_identical(what_is_it(mtcars), "a data frame")
   expect_identical(what_is_it(factor(letters)), "a factor")
   expect_identical(what_is_it(lm(hp ~ mpg, data = mtcars)), "an object of class 'lm'")
@@ -24,10 +28,12 @@ test_that("S3 objects", {
 })
 
 
-test_that("S4 objects", {
+## Test 4: S4 objects ----
+test_that("what_is_it Test 4: S4 objects", {
   expect_identical(what_is_it(lubridate::days(1)), "a S4 object of class 'Period'")
 })
 
-test_that("symbols", {
+## Test 5: symbols ----
+test_that("what_is_it Test 5: symbols", {
   expect_identical(what_is_it(quote(USUBJID)), "a symbol")
 })
